@@ -603,13 +603,14 @@ void MainImpl::filterList(bool isOn, bool onlyHighlight) {
 	}
 	bool evenLine = false;
 	int visibleCnt = 0;
+	QRegExp re(filter, false, true);
 	QListViewItem* firstItem = NULL;
 	QListView* lv = rv->tab()->listViewLog;
 	QListViewItemIterator it(lv);
 	while (it.current()) {
 		ListViewItem* item = static_cast<ListViewItem*>(it.current());
 		if (isOn) {
-			if (passFilter(item, filter, colNum, shaMap)) {
+			if (passFilter(item, re, colNum, shaMap)) {
 				if (onlyHighlight)
 					item->setHighlighted(true);
 				else {
@@ -655,7 +656,7 @@ void MainImpl::filterList(bool isOn, bool onlyHighlight) {
 	QApplication::postEvent(rv, new MessageEvent(msg));
 }
 
-bool MainImpl::passFilter(ListViewItem* item, SCRef filter, int colNum,
+bool MainImpl::passFilter(ListViewItem* item, const QRegExp& filter, int colNum,
                           const QMap<QString, bool>& shaMap) {
 
 	if (colNum == SHA_MAP_COL)
@@ -680,7 +681,7 @@ bool MainImpl::passFilter(ListViewItem* item, SCRef filter, int colNum,
 			field = item->sha();
 	}
 	// wildcard search, case insensitive
-	return (field.find(QRegExp(filter, false, true)) != -1);
+	return (field.find(filter) != -1);
 }
 
 void MainImpl::customEvent(QCustomEvent* e) {
@@ -1319,25 +1320,22 @@ void MainImpl::ActMailFormatPatch_activated() {
 	QApplication::restoreOverrideCursor();
 }
 
-bool MainImpl::askApplyPatchParameters(bool* commit, bool* fold) {
+bool MainImpl::askApplyPatchParameters(bool* workDirOnly, bool* fold) {
 
-	int ret = QMessageBox::question(this, "Apply Patch",
-	          "Do you want to commit or just to apply changes to "
-	          "working directory?", "&Cancel", "&Working dir", "&Commit", 0, 0);
-	if (ret == 0)
-		return false;
-
-	*commit = (ret == 2);
-	*fold = false;
-	if (*commit && git->isStGITStack()) {
+	int ret = 0;
+	if (!git->isStGITStack()) {
+		ret = QMessageBox::question(this, "Apply Patch",
+		      "Do you want to commit or just to apply changes to "
+		      "working directory?", "&Cancel", "&Working dir", "&Commit", 0, 0);
+		*workDirOnly = (ret == 1);
+		*fold = false;
+	} else {
 		ret = QMessageBox::question(this, "Apply Patch", "Do you want to "
 		      "import or fold the patch?", "&Cancel", "&Fold", "&Import", 0, 0);
-		if (ret == 0)
-			return false;
-
+		*workDirOnly = false;
 		*fold = (ret == 1);
 	}
-	return true;
+	return (ret != 0);
 }
 
 void MainImpl::ActMailApplyPatch_activated() {
@@ -1352,13 +1350,14 @@ void MainImpl::ActMailApplyPatch_activated() {
 	QFileInfo f(patchName);
 	settings.writeEntry(APP_KEY + FP_DIR_KEY, f.dirPath(true));
 
-	bool commit, fold;
-	if (!askApplyPatchParameters(&commit, &fold))
+	bool workDirOnly, fold;
+	if (!askApplyPatchParameters(&workDirOnly, &fold))
 		return;
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-	if (git->applyPatchFile(f.absFilePath(), commit, fold, !Git::optDragDrop) && !commit)
+	bool ok = git->applyPatchFile(f.absFilePath(), fold, !Git::optDragDrop);
+	if (workDirOnly && ok)
 		git->resetCommits(1);
 
 	QApplication::restoreOverrideCursor();
